@@ -14,6 +14,11 @@ class Region(object):
         if ':' in region:
             try:
                 self.chromosome, interval = region.replace(',', '').split(':')
+                try:
+                    # see if just integer chromosomes are used
+                    self.chromosome = int(self.chromosome)
+                except ValueError:
+                    pass
                 self.begin, self.end = [int(i) for i in interval.split('-')]
             except ValueError:
                 sys.exit("\n\nERROR: Window (-w/--window) inproperly formatted, "
@@ -157,6 +162,15 @@ def is_cram_file(filepath):
         return test_f.read(4) == b'CRAM'
 
 
+def is_bam_file(filepath):
+    import gzip
+    try:
+        with gzip.open(filepath) as test_f:
+            return test_f.read(3) == b'BAM'
+    except OSError:
+        return False
+
+
 def file_sniffer(filename):
     """
     Takes in a filename and tries to guess the input file type
@@ -165,6 +179,8 @@ def file_sniffer(filename):
         sys.exit(f"\n\nERROR: File {filename} does not exist, please check the path!\n")
     if is_cram_file(filename):
         return "ont-cram"
+    if is_bam_file(filename):
+        return "bam"
     if is_gz_file(filename):
         import gzip
         header = gzip.open(filename, 'rt').readline()
